@@ -7,7 +7,7 @@ use Getopt::Long;# 2.33;
 use urpm::download;
 use urpm::msg;
 
-(our $VERSION) = q$Id: args.pm,v 1.83 2005/12/06 11:24:33 rgarciasuarez Exp $ =~ /(\d+\.\d+)/;
+(our $VERSION) = q$Id: args.pm,v 1.85 2005/12/22 15:14:34 rgarciasuarez Exp $ =~ /(\d+\.\d+)/;
 
 # The program that invokes us
 (my $tool = $0) =~ s!.*/!!;
@@ -68,6 +68,7 @@ my %options_spec = (
 	'allow-medium-change' => \$::allow_medium_change,
 	'gui' => \$::gui,
 	'auto-select' => \$::auto_select,
+	'auto-update' => sub { $::auto_update = $::auto_select = 1 },
 	'no-remove|no-uninstall' => \$::no_remove,
 	'no-install' => \$::no_install,
 	keep => sub { $urpm->{options}{keep} = 1 },
@@ -145,6 +146,7 @@ my %options_spec = (
 	auto => \$::auto,
 	v => \$::verbose,
 	a => \$::matches,
+	noscripts => \$::noscripts,
     },
 
     #- see also below, autogenerated callbacks
